@@ -107,8 +107,11 @@ class Idcard_Malaysia():
             address, state = self.__get_address(text_list)
             print (address)
             print (ic_number)
-            
-        return ic_number, full_name, gender, dob, address, state
+        
+        result = {"ic_number": ic_number, "name": full_name, 
+                  "gender": gender, "dob": dob, 
+                  "address": address, "state": state}
+        return result
 
 
 class Idcard_Singapore(): 
@@ -139,7 +142,11 @@ class Idcard_Singapore():
         print (num_ic) 
         print (dob)
         print (gender)
-        return name, num_ic, dob, gender, address, state
+
+        result = {"ic_number": num_ic, "name": name, 
+                  "gender": gender, "dob": dob, 
+                  "address": address, "state": state}
+        return result
 
 
 class Idcard_Vietnam(): 
@@ -173,6 +180,9 @@ class Idcard_Vietnam():
         print (gender)
         print (address)
         print (state)
+        result = {"ic_number": num_ic, "name": name, 
+                  "gender": gender, "dob": dob, 
+                  "address": address, "state": state}
         return name, num_ic, dob, gender, address, state
 
 
@@ -210,3 +220,10 @@ class Idcard_Thailand():
         print (gender)
         print (address)
         print (state)
+
+        result = {"ic_number": num_ic, "name": name, 
+                  "gender": gender, "dob": dob, 
+                  "address": address, "state": state}
+
+        return result 
+        
